@@ -115,7 +115,7 @@ def fis_get_colors(theme):
         dark_theme_colors + ["#ea5545", "#f46a9b", "#ef9b20", "#edbf33", "#ede15b", "#bdcf32", "#87bc45", "#27aeef", "#b33dc6"]
         return dark_theme_colors
     elif theme == 'business':
-        business_colors = ["#D6D7D9","#97ACCF","#A7A8AA","#B6E1F6","#DAE3F3",""#2f6997","#7A7B7D","#00b7c7","#505153","#8bd3c7","#3E4756","#0d88e6"]        
+        business_colors = ["#D6D7D9","#97ACCF","#A7A8AA","#B6E1F6","#DAE3F3","#2f6997","#7A7B7D","#00b7c7","#505153","#8bd3c7","#3E4756","#0d88e6"]        
         return business_colors
     else:
         return None
